# Yuio

Yuio is everything you'll ever need to write a good CLI, deps-free.

Forget searching for *that one progressbar library*,
figuring out how to keep loading configs DRY,
or having headaches because autocompletion was just an afterthought.
Yuio got you.

---

![A video demonstrating Yuio features: colored output, multiple progressbars, interactive widgets.](https://taminomara.github.io/yuio/_images/vhs-efe1eaeed8d602666b7c93d0178b061328bb654cf5e4a3def19103de8e4402bd.gif "Demo of Yuio features")

---

## Resources

- [Documentation](https://yuio.readthedocs.io/)
- [Issues](https://github.com/taminomara/yuio/issues)
- [Source](https://github.com/taminomara/yuio/)
- [PyPi](https://pypi.org/project/yuio/)
- [Changelog](https://github.com/taminomara/yuio/blob/main/CHANGELOG.md)

## Requirements

The only requirement is `python >= 3.10`.

## Installation

Install `yuio` with pip:

```sh
pip3 install yuio
```

Or just copy-paste the `yuio` directory to somewhere in the `PYTHONPATH` of your project.
